package com.sundata.internalevaluation.calc.util;

import cn.hutool.extra.spring.SpringUtil;
import com.sundata.internalevaluation.calc.calcUnit.RulesCalcUnit;
import com.sundata.internalevaluation.calc.model.CalcException;
import com.sundata.internalevaluation.calc.model.CalcUnit;
import com.sundata.internalevaluation.calc.running.CalcRunning;
import com.sundata.internalevaluation.calc.running.threads.CalcTaskResult;
import com.sundata.internalevaluation.configuration.model.SysReqRules;
import com.sundata.internalevaluation.configuration.service.SysReqRuleService;
import com.sundata.internalevaluation.configuration.service.SysReqRulesService;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;

/**
 * 计算工具类
 */
public class CalcUtil {
    /**
     * 调用计算的过程
     * @param calculateInstanceNumber 计算流水号
     * @param calcUnit 计算节点
     * @param context 计算参数
     * @return 计算结果
     */
    public static CalcTaskResult calc(String calculateInstanceNumber, CalcUnit calcUnit, Map<String, Object> context) {
        return new CalcRunning().startCalc(calculateInstanceNumber, calcUnit, context);
    }

    /**
     * 计算规则
     * @param calculateInstanceNumber 计算流水号
     * @param rulesNo 规则集编号
     * @param context 参数  网贷传入的报文
     * @return 计算结果
     */
    public static CalcTaskResult calcRules(String calculateInstanceNumber, String rulesNo, Map<String, Object> context) {
        if (StringUtils.isNotBlank(rulesNo)) {
            throw new CalcException("数据集编号不能为空！！！");
        }
        SysReqRulesService rulesService = SpringUtil.getBean(SysReqRulesService.class);
        SysReqRules rules = rulesService.getById(rulesNo);

        CalcUnit calcUnit = new RulesCalcUnit(rules.getRulesNo(),rules.getRulesName(),Map.of(),rules,SpringUtil.getBean(SysReqRuleService.class));
        return calc(calculateInstanceNumber, calcUnit, context);
    }
}
