package com.sundata.internalevaluation.configuration.service;

import com.sundata.common.exception.BusinessException;
import com.sundata.common.util.JsonUtil;
import com.sundata.internalevaluation.configuration.controller.DataSetConfigAction;
import com.sundata.internalevaluation.configuration.mapper.DataSetConfigMapper;
import com.sundata.internalevaluation.configuration.model.DataSetConfigModel;
import com.sundata.internalevaluation.configuration.model.DataSourcesModel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class DataSetConfigService {
    static final Logger log = LoggerFactory.getLogger(DataSetConfigService.class);

    @Autowired
    DataSetConfigMapper dataSetConfigMapper;

    /**
     * @author: 张艳杰
     * @methodsName: getDataList
     * @description: 数据集配置初始化
     * @param: DataSetConfigModel model
     * @return: List<DataSetConfigModel>
     * @throws:
     */
    public List<DataSetConfigModel> getDataList(DataSetConfigModel model) {
        String dataSourceNo = JsonUtil.toJSONString(model.getDataSourcesNos());
        model.setDataSetNo(dataSourceNo);
        return dataSetConfigMapper.getDataList(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置新增
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void createData(DataSetConfigModel model) {
        String dataSourceNo = JsonUtil.toJSONString(model.getDataSourcesNos());
        model.setDataSetNo(dataSourceNo);
        dataSetConfigMapper.createData(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置删除
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void deleteRows(DataSetConfigModel model) {
        dataSetConfigMapper.deleteRows(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: createData
     * @description: 数据集配置修改
     * @param: IndexConfigModel model
     * @return:
     * @throws:
     */
    public void updateExistData(DataSetConfigModel model) {
        String dataSourceNo = JsonUtil.toJSONString(model.getDataSourcesNos());
        model.setDataSetNo(dataSourceNo);
        dataSetConfigMapper.updateExistData(model);
    }

    /**
     * @author: 张艳杰
     * @methodsName: selectDetailData
     * @description: 数据来源配置查询
     * @param:  DataSetConfigModel model
     * @return:
     * @throws:
     */
    public DataSetConfigModel selectDetailData(DataSetConfigModel model) {
        DataSetConfigModel configModel = dataSetConfigMapper.selectDetailData(model);
        model.setDataSourcesNos(JsonUtil.jsonToList(configModel.getDataSetNo()));
        return dataSetConfigMapper.selectDetailData(model);
    }
}
