package com.sundata.internalevaluation.configuration.service;

import com.sundata.common.base.ActiveUserService;
import com.sundata.common.login.ActiveUser;
import com.sundata.common.util.DateUtil;
import com.sundata.internalevaluation.configuration.mapper.SysInterfaceMapper;
import com.sundata.internalevaluation.configuration.model.SysInterface;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.UUID;

/**
 * @author JoeLazy
 */
@Service
public class SysInterfaceService {

    @Autowired
    private SysInterfaceMapper sysInterfaceMapper;


    @Autowired
    private SysInterfaceParamService paramService;

    /**
     * 查询所有记录
     *
     * @return 返回集合，没有返回空List
     */
    public List<SysInterface> listAll(SysInterface sysInterface) {
    	return sysInterfaceMapper.listAll(sysInterface);
    }


    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 返回记录，没有返回null
     */
    public SysInterface getById(String id) {
        return sysInterfaceMapper.getById(id);
    }
	
    /**
     * 新增，插入所有字段
     *
     * @param sysInterface 新增的记录
     * @return 返回影响行数
     */
    public int insert(SysInterface sysInterface) {
    	return sysInterfaceMapper.insert(sysInterface);
    }
	
    /**
     * 新增，忽略null字段
     *
     * @param sysInterface 新增的记录
     * @return 返回影响行数
     */

    @Transactional
    public int insertIgnoreNull(SysInterface sysInterface) {
//        Long snowflakeId = IdUtils.getSnowflakeId();
        String snowflakeId =  UUID.randomUUID().toString();
        sysInterface.setId(snowflakeId);
        ActiveUser activeUser = ActiveUserService.readActiveUser();
        String account = activeUser.getAccount();
        sysInterface.setCreateBy(account);
        sysInterface.setUpdateBy(account);
        String nowTime = DateUtil.getCurTime();
        sysInterface.setCreateTime(nowTime);
        sysInterface.setUpdateTime(nowTime);
        String interfaceId = sysInterface.getId();
        paramService.deleteByInterfaceId(interfaceId);
        paramService.insertBatch(sysInterface.getParamList(), interfaceId);
        return sysInterfaceMapper.insertIgnoreNull(sysInterface);
    }
	
    /**
     * 修改，修改所有字段
     *
     * @param sysInterface 修改的记录
     * @return 返回影响行数
     */
    @Transactional
    public int update(SysInterface sysInterface) {
        ActiveUser activeUser = ActiveUserService.readActiveUser();
        String account = activeUser.getAccount();
        sysInterface.setUpdateBy(account);
        String nowTime = DateUtil.getCurTime();
        sysInterface.setUpdateTime(nowTime);
        String interfaceId = sysInterface.getId();
        paramService.deleteByInterfaceId(interfaceId);
        paramService.insertBatch(sysInterface.getParamList(), interfaceId);
    	return updateIgnoreNull(sysInterface);
    }
	
    /**
     * 修改，忽略null字段
     *
     * @param sysInterface 修改的记录
     * @return 返回影响行数
     */
    public int updateIgnoreNull(SysInterface sysInterface) {
    	return sysInterfaceMapper.updateIgnoreNull(sysInterface);
    }
	
    /**
     * 删除记录
     *
     * @param sysInterface 待删除的记录
     * @return 返回影响行数
     */
    @Transactional
    public int delete(SysInterface sysInterface) {
        paramService.deleteByInterfaceId(sysInterface.getId());
    	return sysInterfaceMapper.delete(sysInterface);
    }
	
}