package com.sundata.internalevaluation.script.model;

import cn.hutool.core.util.StrUtil;
import org.jetbrains.annotations.Nullable;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;

public class TemplateRunningModel {
    private String runningId;
    private TemplateModel templateModel;
    private Map<String,Object> variables;

    @Override
    public String toString() {
        return new StringJoiner(", ", TemplateRunningModel.class.getSimpleName() + "[", "]")
                .add("runningId='" + runningId + "'")
                .add("templateModel=" + templateModel)
                .add("variables=" + variables)
                .toString();
    }

    @Override
    public boolean equals(Object o) {
        if (o == null || getClass() != o.getClass()) return false;

        TemplateRunningModel that = (TemplateRunningModel) o;
        return Objects.equals(getRunningId(), that.getRunningId()) && Objects.equals(getTemplate(), that.getTemplate()) && Objects.equals(getVariables(), that.getVariables());
    }

    @Override
    public int hashCode() {
        int result = Objects.hashCode(getRunningId());
        result = 31 * result + Objects.hashCode(getTemplate());
        result = 31 * result + Objects.hashCode(getVariables());
        return result;
    }

    public String getRunningId() {
        return runningId;
    }

    public void setRunningId(String runningId) {
        this.runningId = runningId;
    }

    public TemplateModel getTemplate() {
        return templateModel;
    }

    public void setTemplate(TemplateModel templateModel) {
        this.templateModel = templateModel;
    }

    public Map<String, Object> getVariables() {
        return variables;
    }

    public void setVariables(Map<String, Object> variables) {
        this.variables = variables;
    }


    public TemplateRunningModel(@Nullable String runningId, @Nullable TemplateModel templateModel,@Nullable Map<String, Object> variables) {
        if (StrUtil.isEmpty(runningId)) {
            throw new IllegalArgumentException("runningId is null");
        }
        if (templateModel == null) {
            throw new IllegalArgumentException("templateModel is null");
        }
        if (variables == null) {
            throw new IllegalArgumentException("variables is null");
        }
        this.runningId = runningId;
        this.templateModel = templateModel;
        this.variables = variables;
    }
}
