package com.sundata.internalevaluation.script.pool;

import groovy.text.Template;
import org.apache.commons.pool2.ObjectPool;
import org.apache.commons.pool2.impl.GenericObjectPool;
import com.sundata.internalevaluation.script.model.TemplateModel;

import java.util.Map;

public class GroovyTemplatePool {
    // 创建一个 GroovyShell 的池
    public static ObjectPool<Template> templateFactoryObjectPool(TemplateModel templateModel) {
        GroovyTemplateFactory factory = new GroovyTemplateFactory(templateModel);
        GenericObjectPool<Template> pool = new GenericObjectPool<>(factory);
        // 配置池的参数，例如最大空闲实例数、最小空闲实例数等
        pool.setMaxIdle(10);
        pool.setMinIdle(2);
        pool.setMaxTotal(20);
        pool.setTestOnBorrow(true);
        pool.setTestOnReturn(true);
        return pool;
    }

    public static void main(String[] args) throws Exception {
        // 定义模板文本
        String templateText = "Hello, ${name}!";

        // 创建 TemplateModel 对象的池
        ObjectPool<Template> templatePool = templateFactoryObjectPool(new TemplateModel("1", templateText));

        // 从池中借用一个 TemplateModel 对象
        Template template = null;
        try {
            template = templatePool.borrowObject();

            // 使用模板生成文本
            String result = template.make(Map.of("name", "World")).toString();
            System.out.println(result);  // 输出: Hello, World!
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            // 使用完后将 TemplateModel 对象归还到池中
            if (template != null) {
                templatePool.returnObject(template);
            }

            // 程序结束时，可以根据需要关闭池以释放资源
            templatePool.close();
        }
    }
}